#!/bin/sh

usage ()
{
    echo "`basename $0` [-d <rep_doc>] [-i <rep_images>] <fic>"
}

RepStart="`pwd`"
RepImages="../images"
RepDoc="$RepStart"

[ $# -lt 1 ] && usage && exit 1

while getopts "d:i:" opt
do
    case "$opt" in
        d) RepDoc="$OPTARG"
           ;;
        i) RepImages="$OPTARG"
           ;;
    esac
done

shift `expr $OPTIND - 1`
FicDonnees="$1"
[ ! -f "$FicDonnees" ] && echo >&2 "Erreur : $FicDonnees n'est pas un fichier" \
&& exit 1

! echo $FicDonnees | grep "^/" && FicDonnees="$RepStart/$FicDonnees"

cd `dirname $0`

[ ! -d $RepDoc/$Nom/$RepImages ] && mkdir -p $RepDoc/$Nom/$RepImages && \
cp -r $RepImages $RepDoc

ImagePrecedent="$RepImages/prev.gif"
ImageSuivant="$RepImages/next.gif"
ImageDebut="$RepImages/start.gif"
Tab1="$RepImages/blue.gif"
Tab2="$RepImages/green.gif"

M4="m4"

if [ "`uname -s`" = "FreeBSD" ]
then
    if [ -x `which gm4` ]
    then
        M4="gm4"
    else
        echo "Sur FreeBSD gm4 non installe" >&2
        exit 1
    fi
fi

Nom=`basename $FicDonnees | sed "s/\.[^\.]*$//" #sed "s/\..*$//"`
NbSlide=`grep -c "<slide>" $FicDonnees`
NoSlide=0

rm -rf $RepDoc/$Nom && mkdir $RepDoc/$Nom

Images=`grep -i "<img " $FicDonnees | grep -v "http://" | \
        sed -e "s/.*src=\([^ ]*\).*/\1/" -e "s/\"//g" -e "s/>//g"`

for img in $Images
do
[ -f /tmp/slide.$$ ] && FicDonnees="/tmp/slide.$$"
    NomImage=`basename $img`
    sed "s;$img;$NomImage;g" < $FicDonnees > /tmp/slide.$NomImage.$$
    mv -f /tmp/slide.$NomImage.$$ /tmp/slide.$$
    cp `eval echo $img` $RepDoc/$Nom
done

cat $FicDonnees | sed \
-e "s,		,<p>\&nbsp;\&nbsp;\&nbsp;\&nbsp;<img src=\"$Tab2\" alt=\"-\" height=\"14\" width=\"14\">\&nbsp;," \
-e "s,	,<p><img src=\"$Tab1\" alt=\"*\" height=\"14\" width=\"14\">\&nbsp;," | \
while read ligne
do

#
# Nouvelle presentation
#

    if echo "$ligne" | grep "<presentation>" > /dev/null
    then

#
# Generer le debut des fichiers index.html, toc.html et la version
# << tout en un >>
#

        echo -e "TITRE()\nENTETE" >> $RepDoc/$Nom/index.m4
        echo -e "TITRE(Plan)\nENTETE" >> $RepDoc/$Nom/toc.m4
        echo -e "TITRE($Nom)\nENTETE" >> $RepDoc/$Nom/$Nom.m4

#
# Page de presentation (index.html) - suite et fin
#

        while read ligne && (! echo "$ligne" | grep "<slide>") > /dev/null
        do
            Titre=`echo $ligne | sed "s/TITRE(\(.*\))/\1/"`
            if echo "$ligne" | grep "TITRE(.*)" > /dev/null
            then
                cat << EOF >> $RepDoc/$Nom/index.m4
TITREINDEX($Titre)
INDEX
EOF
            fi
        done
        echo "PIED" >> $RepDoc/$Nom/index.m4

        $M4 ./look.m4 $RepDoc/$Nom/index.m4 \
        -DNoSlide="$NoSlide" -DNbSlide="$NbSlide" \
        -DIMGPREV="$ImagePrecedent" -DIMGSUIV="$ImageSuivant" \
        -DPRECEDENT="$Nom-$NbSlide.html" -DSUIVANT="toc.html" \
        -DIMGSTART="$ImageDebut" -DIMGDIR="$RepImages" \
        > $RepDoc/$Nom/index.html
        echo "$RepDoc/$Nom/index.html"
    fi

#
# Lit les lignes jusqu'au premier slide
#

    ! echo "$ligne" | grep "<slide>" > /dev/null && continue

    NoSlide=`expr $NoSlide + 1`
    LeNomM4="$Nom-$NoSlide.m4"
    LeNomHTML="$Nom-$NoSlide.html"

    if [ $NoSlide -eq 1 ]
    then
        Precedent="toc.html"
    else
        Precedent="$Nom-`expr $NoSlide - 1`.html"
    fi

    if [ $NoSlide -eq $NbSlide ]
    then
        Suivant="index.html"
    else
        Suivant="$Nom-`expr $NoSlide + 1`.html"
    fi

#
# Lit jusque la fin du slide courant
#

    while read ligne && (! echo "$ligne" | grep "</slide>") > /dev/null
    do

#
# Si la ligne contient TITRE(...) il faut generer l'en-tete de ce slide...
#

        if (echo "$ligne" | grep "TITRE(.*)" > /dev/null) && [ -z "$Titre" ]
        then
            Titre="$ligne"
            TitreSeul=`echo $ligne | sed "s/TITRE(\(.*\))/\1/"`
            echo -e "$Titre\nENTETE" >> $RepDoc/$Nom/$LeNomM4

#
# ... ajouter le titre dans la version << tout en un >>
#

            echo "<p><hr>$TitreSeul<hr>" >> $RepDoc/$Nom/$Nom.m4

#
# ... et ajouter ce titre dans l'index
#

            echo "<p><img src=\"$Tab1\">&nbsp;<a href=\"$LeNomHTML\">$TitreSeul</a>" >> $RepDoc/$Nom/toc.m4
        else

#
# Sinon la ligne est copiee telle quelle dans le slide courant et dans la
# version << tout en un >>
#

            echo "$ligne" >> $RepDoc/$Nom/$LeNomM4
            echo "$ligne" >> $RepDoc/$Nom/$Nom.m4
        fi
    done
    echo "PIED" >> $RepDoc/$Nom/$LeNomM4

    $M4 ./look.m4 $RepDoc/$Nom/$LeNomM4 \
    -DNoSlide="$NoSlide" -DNbSlide="$NbSlide" \
    -DIMGPREV="$ImagePrecedent" -DIMGSUIV="$ImageSuivant" \
    -DPRECEDENT="$Precedent" -DSUIVANT="$Suivant" \
    -DIMGSTART="$ImageDebut" -DCOMPTE -DIMGDIR="$RepImages" \
    > $RepDoc/$Nom/$LeNomHTML
#    cat $RepDoc/$Nom/$LeNomHTML >> $RepDoc/$Nom/$Nom.html
    echo $RepDoc/$Nom/$LeNomHTML
    Titre=""
done

#
# Generer la fin des fichiers toc.html et << tout en un >>
#

echo "PIED" >> $RepDoc/$Nom/toc.m4

$M4 ./look.m4 $RepDoc/$Nom/toc.m4 \
    -DNoSlide="$NoSlide" -DNbSlide="$NbSlide" \
    -DIMGPREV="$ImagePrecedent" -DIMGSUIV="$ImageSuivant" \
    -DPRECEDENT="index.html" -DSUIVANT="$Nom-1.html" \
    -DIMGSTART="$ImageDebut" -DIMGDIR="$RepImages" \
    > $RepDoc/$Nom/toc.html
echo "$RepDoc/$Nom/toc.html"

echo "PIED" >> $RepDoc/$Nom/$Nom.m4

$M4 ./look.m4 $RepDoc/$Nom/$Nom.m4 \
    -DNoSlide="$NoSlide" -DNbSlide="$NbSlide" \
    -DIMGPREV="$ImagePrecedent" -DIMGSUIV="$ImageSuivant" \
    -DPRECEDENT="index.html" -DSUIVANT="$Nom-1.html" \
    -DIMGSTART="$ImageDebut" -DIMGDIR="$RepImages" \
    > $RepDoc/$Nom/$Nom.html
echo "$RepDoc/$Nom/$Nom.html"

cp ../look.css $RepDoc/$Nom

echo "$RepDoc/$Nom/$Nom.ps"
#html2ps $RepDoc/$Nom/$Nom.html > $RepDoc/$Nom/$Nom.ps

exit 0
