#!/bin/sh

usage ()
{
    echo "`basename $0` [-d <rep_doc>] [-i <rep_images>] <fic>"
}

Date="`date +%d/%m/%y`"
Annee="`date +%Y`"
Hostname="`hostname`"
Moi="Mathieu DECORE"

RepStart="`pwd`"
RepImages="../images"
RepDoc="$RepStart"

Xfig_x=500
Xfig_y=3500

[ $# -lt 1 ] && usage && exit 1

while getopts "d:i:" opt
do
    case "$opt" in
        d) RepDoc="$OPTARG"
           ;;
        i) RepImages="$OPTARG"
           ;;
    esac
done

shift `expr $OPTIND - 1`
FicDonnees="$1"
[ ! -f "$FicDonnees" ] && echo >&2 "Erreur : $FicDonnees n'est pas un fichier" \
&& exit 1

! echo $FicDonnees | grep "^/" && FicDonnees="$RepStart/$FicDonnees"

cd `dirname $0`

ImagePrecedent="$RepImages/prev.gif"
ImageSuivant="$RepImages/next.gif"
ImageDebut="$RepImages/start.gif"
Tab1="$RepImages/blue.gif"
Tab2="$RepImages/green.gif"

Nom=`basename $FicDonnees | sed "s/\.[^\.]*$//" # sed "s/\..*$//"`
NbSlide=`grep -c "<slide>" $FicDonnees`
NoSlide=0

[ ! -d $RepDoc/$Nom/$RepImages ] && mkdir -p $RepDoc/$Nom/$RepImages && \
cp -r $RepImages $RepDoc

rm -rf $RepDoc/$Nom && mkdir $RepDoc/$Nom

Images=`grep -i "<img " $FicDonnees | grep -v "http://" | \
        sed -e "s/.*src=\([^ ]*\).*/\1/" -e "s/\"//g" -e "s/>//g"`

for img in $Images
do
[ -f /tmp/slide.$$ ] && FicDonnees="/tmp/slide.$$"
    NomImage=`basename $img`
    sed "s;$img;$NomImage;g" < $FicDonnees > /tmp/slide.$NomImage.$$
    mv -f /tmp/slide.$NomImage.$$ /tmp/slide.$$
    cp `eval echo $img` $RepDoc/$Nom
done

cat $FicDonnees | sed \
-e "s,		,<p>\&nbsp;\&nbsp;\&nbsp;\&nbsp;<img src=\"$Tab2\" alt=\"-\" height=\"14\" width=\"14\">\&nbsp;," \
-e "s,	,<p><img src=\"$Tab1\" alt=\"*\" height=\"14\" width=\"14\">\&nbsp;," | \
while read ligne
do

#
# Nouvelle presentation
#

    if echo "$ligne" | grep "<presentation>" > /dev/null
    then

#
# Generer le debut des fichiers index.html, toc.html et la version
# << tout en un >>
#

        sed \
            -e "s;_DATE_;$Date;" \
            -e "s;_USER_;$USER;" \
            -e "s;_HOSTNAME_;$Hostname;" \
            -e "s;_TITRE_;;" \
            -e "s;IMGSTART;$ImageDebut;" \
            -e "s;IMGPREV;$ImagePrecedent;" \
            -e "s;PRECEDENT;$Nom-$NbSlide.html;" \
            -e "s;SUIVANT;toc.html;" \
            -e "s;IMGSUIV;$ImageSuivant;" \
            < ./header >> $RepDoc/$Nom/index.html

        sed \
            -e "s;_DATE_;$Date;" \
            -e "s;_USER_;$USER;" \
            -e "s;_HOSTNAME_;$Hostname;" \
            -e "s;_TITRE_;Plan;" \
            -e "s;IMGSTART;$ImageDebut;" \
            -e "s;IMGPREV;$ImagePrecedent;" \
            -e "s;PRECEDENT;index.html;" \
            -e "s;SUIVANT;$Nom-1.html;" \
            -e "s;IMGSUIV;$ImageSuivant;" \
            < ./header >> $RepDoc/$Nom/toc.html

        sed \
            -e "s;_DATE_;$Date;" \
            -e "s;_USER_;$USER;" \
            -e "s;_HOSTNAME_;$Hostname;" \
            -e "s;_TITRE_;$Nom;" \
            -e "s;IMGSTART;$ImageDebut;" \
            -e "s;IMGPREV;$ImagePrecedent;" \
            -e "s;PRECEDENT;$Nom-$NbSlide.html;" \
            -e "s;SUIVANT;toc.html;" \
            -e "s;IMGSUIV;$ImageSuivant;" \
            < ./header-tt-en-un >> $RepDoc/$Nom/$Nom.html

    cat << EOF >> $RepDoc/$Nom/$Nom.fig
#FIG 3.2
Landscape
Center
Inches
A4
100.00
Single
-2
1200 2
EOF

#
# Page de presentation (index.html) -  suite et fin
#

        while read ligne && (! echo "$ligne" | grep "<slide>") > /dev/null
        do
            Titre=`echo $ligne | sed "s/TITRE(\(.*\))/\1/"`
            if echo "$ligne" | grep "TITRE(.*)" > /dev/null
            then
                sed \
                    -e "s/_INDEX_/$Titre/" \
                    -e "s/_MOI_/$Moi/" \
                    < ./index >> $RepDoc/$Nom/index.html
            fi
        done
        sed \
            -e "s;IMGDIR;$RepImages;" \
            -e "s;_MOI_;$Moi;" \
            -e "s;_DATE_;$Date;" \
            -e "s;_ANNEE_;$Annee;" \
            < ./footer >> $RepDoc/$Nom/index.html
        echo "$RepDoc/$Nom/index.html"
    fi

#
# Lit les lignes jusqu'au premier slide
#

    ! echo "$ligne" | grep "<slide>" > /dev/null && continue

    NoSlide=`expr $NoSlide + 1`
    LeNomHTML="$Nom-$NoSlide.html"

    if [ $NoSlide -eq 1 ]
    then
        Precedent="toc.html"
    else
        Precedent="$Nom-`expr $NoSlide - 1`.html"
    fi

    if [ $NoSlide -eq $NbSlide ]
    then
        Suivant="index.html"
    else
        Suivant="$Nom-`expr $NoSlide + 1`.html"
    fi

#
# Lit jusque la fin du slide courant
#

    while read ligne && (! echo "$ligne" | grep "</slide>") > /dev/null
    do

#
# Si la ligne contient TITRE(...) il faut generer l'en-tete de ce slide...
#

        if echo "$ligne" | grep "TITRE(.*)" > /dev/null && [ -z "$Titre" ]
        then
            Titre=`echo $ligne | sed "s/TITRE(\(.*\))/\1/"`
            sed \
                -e "s;_DATE_;$Date;" \
                -e "s;_USER_;$USER;" \
                -e "s;_HOSTNAME_;$Hostname;" \
                -e "s;_TITRE_;$Titre;" \
                -e "s;IMGSTART;$ImageDebut;" \
                -e "s;IMGPREV;$ImagePrecedent;" \
                -e "s;PRECEDENT;$Precedent;" \
                -e "s;SUIVANT;$Suivant;" \
                -e "s;IMGSUIV;$ImageSuivant;" \
                < ./header >> $RepDoc/$Nom/$LeNomHTML

#
# ... ajouter ce titre dans la version << tout en un >>
#

                echo "<p><hr><h1>$Titre</h1><hr>" >> $RepDoc/$Nom/$Nom.html

#
# ... ajouter ce titre dans la version Xfig
#

                cat << EOF >> $RepDoc/$Nom/$Nom.fig
# $Titre
EOF

#
# ... et ajouter ce titre dans l'index
#

            cat << EOF >> $RepDoc/$Nom/toc.html
<p><img src="$Tab1">&nbsp;<a href="$LeNomHTML">
`echo $ligne | sed "s/TITRE(\(.*\))/\1/"`
</a>
EOF

    Texte_x=`expr \`echo $Titre | wc -c\` \* 75`
    Rayon_x=`expr $Texte_x / 2 + 50`
    Centre_x=`expr $Xfig_x + $Texte_x / 2`
#echo $Centre_x $Titre
    Rayon_y=400

    Couleur=$NoSlide
    Style=10

    cat << EOF >> $RepDoc/$Nom/$Nom.fig
# Ellipse de rayon ($Rayon_x, $Rayon_y) centre en ($Centre_x, $Xfig_y)
# Couleur $Couleur : Style $Style
1 1 0 1 0 $Couleur 50 0 $Style 0.000 1 0.0000 $Centre_x $Xfig_y $Rayon_x $Rayon_y 0 0 0 0
#1 1 0 1 0 `expr $Couleur + 1` 50 0 $Style 0.000 1 0.0000 $Centre_x `expr $Xfig_y + 500` $Rayon_x $Rayon_y 0 0 0 0
# Texte justifie au coin bas gauche en ($Xfig_x, $Xfig_y)
4 0 7 50 0 0 12 0.0000 4 135 630 $Xfig_x $Xfig_y $Titre\001
EOF

    Xfig_x=`expr $Xfig_x + $Texte_x + 275`

        else

#
# Sinon la ligne est copiee telle quelle dans le slide courant et dans la
# version << tout en un >>
#

            echo "$ligne" >> $RepDoc/$Nom/$LeNomHTML
            echo "$ligne" >> $RepDoc/$Nom/$Nom.html
        fi
    done

    cat ./footer ./compte | sed \
        -e "s;IMGDIR;$RepImages;" \
        -e "s;_MOI_;$Moi;" \
        -e "s;_DATE_;$Date;" \
        -e "s;_ANNEE_;$Annee;" \
        -e "s;NoSlide;$NoSlide;" \
        -e "s;NbSlide;$NbSlide;" \
        >> $RepDoc/$Nom/$LeNomHTML

#    cat $RepDoc/$Nom/$LeNomHTML >> $RepDoc/$Nom/$Nom.html
    echo $RepDoc/$Nom/$LeNomHTML
    Titre=""
done

#
# Generer la fin des fichiers toc.html et << tout en un >>
#

sed \
    -e "s;IMGDIR;$RepImages;" \
    -e "s;_MOI_;$Moi;" \
    -e "s;_DATE_;$Date;" \
    -e "s;_ANNEE_;$Annee;" \
    < ./footer >> $RepDoc/$Nom/toc.html
echo "$RepDoc/$Nom/toc.html"

sed \
    -e "s;IMGDIR;$RepImages;" \
    -e "s;_MOI_;$Moi;" \
    -e "s;_DATE_;$Date;" \
    -e "s;_ANNEE_;$Annee;" \
    < ./footer-tt-en-un >> $RepDoc/$Nom/$Nom.html
echo "$RepDoc/$Nom/$Nom.html"

cp ../look.css $RepDoc/$Nom

if [ -n "`whereis html2ps | awk '{print $2}'`" ]
then
    echo "$RepDoc/$Nom/$Nom.ps"
    html2ps $RepDoc/$Nom/$Nom.html > $RepDoc/$Nom/$Nom.ps
fi

if [ -n "`whereis fig2dev | awk '{print $2}'`" ]
then
    echo "$RepDoc/$Nom/$Nom.eps"
    fig2dev -L eps -z A4 $RepDoc/$Nom/$Nom.fig $RepDoc/$Nom/$Nom.eps

    echo "$RepDoc/$Nom/$Nom.jpeg"
    fig2dev -L jpeg $RepDoc/$Nom/$Nom.fig $RepDoc/$Nom/$Nom.jpeg
fi

exit 0
